/////////////////////////////////////////////////////////////////
// Ozier, O. (2018)
// "The Impact of Secondary Schooling in Kenya:
//  A Regression Discontinuity Analysis"
// Journal of Human Resources 53(1), pp.157-188
/////////////////////////////////////////////////////////////////
// Table 4, cols 5 and 6
/////////////////////////////////////////////////////////////////
// NOTE:
//
// The paper reports a bootstrap-based standard error procedure.
// This file, however, provides a simpler procedure.
//
// This file calculates the more conservative of two possible standard errors:
//  the standard error from Stata's marginal effects command;
// or
//  a standard error that would produce the z-statistic from Stata's biprobit command
//
// The pattern of results is not changed, though the last row of the published
// table appears to have one coefficient out of place, one erroneous coefficient,
// and for the erroneous coefficient, the published table reports statistical
// insignificance, while this file reports statistical significance (p=0.0001).

/////////////////////////////////////////////////////////////////
// owen ozier
// file started 2009
// file updated 2021
global rootdir "YOURDIRECTORY"
global dodir "${rootdir}\do"
global dtadir "${rootdir}\dta"
global tmpdir "${rootdir}\tmp"

cd $dtadir
use ozier_jhr_rep_data_v1.dta, clear
cd $tmpdir
/////////////////////////////////////////////////////////////////



local absmax=0.8
local biprobit1spec="i.finishsecondary rkcpe int_pass_rkcpe"
local biprobit2spec="finishsecondary=passrkcpe rkcpe int_pass_rkcpe"
tab psdp_std98 , gen(ds)

local controls1="age_at_klps2_approximate ds2-ds6"
local controls2="mothers_education_0_if_missing missing_mothers_education"
local controls3="fathers_education_0_if_missing missing_fathers_education"
local ctrls="`controls1' `controls2' `controls3'"

local bandwidth "abs(rkcpe)<`absmax'"
local oldermale "female==0 & psdp_std98>5"
local female18 "female==1 & age_at_klps2_approximate>=18"



// PANEL A ROW 1

local outcome "employed"

// 5
biprobit (`outcome'=`biprobit1spec') (`biprobit2spec') if `bandwidth' & `oldermale' , vce(cluster rkcpe)
local bp_b=el(r(table),1,2)
local bp_z=el(r(table),3,2)
local bp_p=el(r(table),4,2)
margins, predict(pmarg1) dydx(finishsecondary) 
local mf_b=el(r(table),1,2)
local mf_z=el(r(table),3,2)
local mf_p=el(r(table),4,2)
local max_p=max(`mf_p',`bp_p')
local conservative_z=min(abs(`mf_z'),abs(`bp_z'))
local conservative_z_equiv_mf_se=abs(`mf_b'/`conservative_z')
di "Of p-values from bivariate probit (`bp_p') and from marginal effect calculation (`mf_p') more conservative is `max_p'"
di "Of z-statistics from bivariate probit (`bp_z') and from marginal effect calculation (`mf_z') more conservative (abs) is `conservative_z'"
di "With marginal effect b `mf_b' the SE that is associated with the conservative Z statistic is `conservative_z_equiv_mf_se'"
// table lists SE 0.192, however this procedure yields 0.215

// 6
biprobit (`outcome'=`biprobit1spec' `ctrls' ) (`biprobit2spec' `ctrls' ) if `bandwidth' & `oldermale' , vce(cluster rkcpe)
local bp_b=el(r(table),1,2)
local bp_z=el(r(table),3,2)
local bp_p=el(r(table),4,2)
margins, predict(pmarg1) dydx(finishsecondary) 
local mf_b=el(r(table),1,2)
local mf_z=el(r(table),3,2)
local mf_p=el(r(table),4,2)
local max_p=max(`mf_p',`bp_p')
local conservative_z=min(abs(`mf_z'),abs(`bp_z'))
local conservative_z_equiv_mf_se=abs(`mf_b'/`conservative_z')
di "Of p-values from bivariate probit (`bp_p') and from marginal effect calculation (`mf_p') more conservative is `max_p'"
di "Of z-statistics from bivariate probit (`bp_z') and from marginal effect calculation (`mf_z') more conservative (abs) is `conservative_z'"
di "With marginal effect b `mf_b' the SE that is associated with the conservative Z statistic is `conservative_z_equiv_mf_se'"
// table lists SE 0.171, however this procedure yields 0.163





// PANEL A ROW 2

local outcome "self_employed"


// 5
biprobit (`outcome'=`biprobit1spec') (`biprobit2spec') if `bandwidth' & `oldermale' , vce(cluster rkcpe)
local bp_b=el(r(table),1,2)
local bp_z=el(r(table),3,2)
local bp_p=el(r(table),4,2)
margins, predict(pmarg1) dydx(finishsecondary) 
local mf_b=el(r(table),1,2)
local mf_z=el(r(table),3,2)
local mf_p=el(r(table),4,2)
local max_p=max(`mf_p',`bp_p')
local conservative_z=min(abs(`mf_z'),abs(`bp_z'))
local conservative_z_equiv_mf_se=abs(`mf_b'/`conservative_z')
di "Of p-values from bivariate probit (`bp_p') and from marginal effect calculation (`mf_p') more conservative is `max_p'"
di "Of z-statistics from bivariate probit (`bp_z') and from marginal effect calculation (`mf_z') more conservative (abs) is `conservative_z'"
di "With marginal effect b `mf_b' the SE that is associated with the conservative Z statistic is `conservative_z_equiv_mf_se'"
// table lists SE 0.147, however this procedure yields 0.095

// 6
biprobit (`outcome'=`biprobit1spec' `ctrls' ) (`biprobit2spec' `ctrls' ) if `bandwidth' & `oldermale' , vce(cluster rkcpe)
local bp_b=el(r(table),1,2)
local bp_z=el(r(table),3,2)
local bp_p=el(r(table),4,2)
margins, predict(pmarg1) dydx(finishsecondary) 
local mf_b=el(r(table),1,2)
local mf_z=el(r(table),3,2)
local mf_p=el(r(table),4,2)
local max_p=max(`mf_p',`bp_p')
local conservative_z=min(abs(`mf_z'),abs(`bp_z'))
local conservative_z_equiv_mf_se=abs(`mf_b'/`conservative_z')
di "Of p-values from bivariate probit (`bp_p') and from marginal effect calculation (`mf_p') more conservative is `max_p'"
di "Of z-statistics from bivariate probit (`bp_z') and from marginal effect calculation (`mf_z') more conservative (abs) is `conservative_z'"
di "With marginal effect b `mf_b' the SE that is associated with the conservative Z statistic is `conservative_z_equiv_mf_se'"
// table lists SE 0.136, however this procedure yields 0.126




// PANEL B ROW 1

local outcome "pregnant_by_18"

// 5
biprobit (`outcome'=`biprobit1spec') (`biprobit2spec') if `bandwidth' & `female18' , vce(cluster rkcpe)
local bp_b=el(r(table),1,2)
local bp_z=el(r(table),3,2)
local bp_p=el(r(table),4,2)
margins, predict(pmarg1) dydx(finishsecondary) 
local mf_b=el(r(table),1,2)
local mf_z=el(r(table),3,2)
local mf_p=el(r(table),4,2)
local max_p=max(`mf_p',`bp_p')
local conservative_z=min(abs(`mf_z'),abs(`bp_z'))
local conservative_z_equiv_mf_se=abs(`mf_b'/`conservative_z')
di "Of p-values from bivariate probit (`bp_p') and from marginal effect calculation (`mf_p') more conservative is `max_p'"
di "Of z-statistics from bivariate probit (`bp_z') and from marginal effect calculation (`mf_z') more conservative (abs) is `conservative_z'"
di "With marginal effect b `mf_b' the SE that is associated with the conservative Z statistic is `conservative_z_equiv_mf_se'"

// note this is neither what appears in column 5 or column 6, erroneously?
// table lists marginal effect -0.184 in column 6, however this procedure yields -0.207.
// table lists SE 0.123 in column 6, however this procedure yields 0.054
// this is statistically significant at traditional levels, while the table reports a figure that is not.

// 6 - THOUGH REPORTED IN TABLE 5 IN THE PAPER
biprobit (`outcome'=`biprobit1spec' `ctrls' ) (`biprobit2spec' `ctrls' ) if `bandwidth' & `female18' , vce(cluster rkcpe)
local bp_b=el(r(table),1,2)
local bp_z=el(r(table),3,2)
local bp_p=el(r(table),4,2)
margins, predict(pmarg1) dydx(finishsecondary) 
local mf_b=el(r(table),1,2)
local mf_z=el(r(table),3,2)
local mf_p=el(r(table),4,2)
local max_p=max(`mf_p',`bp_p')
local conservative_z=min(abs(`mf_z'),abs(`bp_z'))
local conservative_z_equiv_mf_se=abs(`mf_b'/`conservative_z')
di "Of p-values from bivariate probit (`bp_p') and from marginal effect calculation (`mf_p') more conservative is `max_p'"
di "Of z-statistics from bivariate probit (`bp_z') and from marginal effect calculation (`mf_z') more conservative (abs) is `conservative_z'"
di "With marginal effect b `mf_b' the SE that is associated with the conservative Z statistic is `conservative_z_equiv_mf_se'"

// note this appears in column 5, erroneously?
// table lists SE 0.086 in column 5, however this procedure yields 0.082

